Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1014)

Unified Diff: media/base/mock_filters.h

Issue 155711: Renamed FilterHost::Error() and Pipeline::GetTime() to more appropriate names. (Closed)
Patch Set: Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/mock_filter_host.h ('k') | media/base/pipeline.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/mock_filters.h
diff --git a/media/base/mock_filters.h b/media/base/mock_filters.h
index 6d8c8a993df58ced66847d7f29da99795de7d2e6..8c449968a23b907577bb45832013d01cb6f180e4 100644
--- a/media/base/mock_filters.h
+++ b/media/base/mock_filters.h
@@ -332,9 +332,9 @@ void RunFilterCallback(::testing::Unused, FilterCallback* callback);
// methods.
void DestroyFilterCallback(::testing::Unused, FilterCallback* callback);
-// Helper gmock action that calls Error() on behalf of the provided filter.
-ACTION_P2(Error, filter, error) {
- filter->host()->Error(error);
+// Helper gmock action that calls SetError() on behalf of the provided filter.
+ACTION_P2(SetError, filter, error) {
+ filter->host()->SetError(error);
}
} // namespace media
« no previous file with comments | « media/base/mock_filter_host.h ('k') | media/base/pipeline.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698